==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/managephones/popupAdd.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 

require('../assets/inc/ldapConnect.php');
$selectedSystemName = (isset($_REQUEST['selectedSystemName']) && strlen($_REQUEST['selectedSystemName']) > 1) ? $_REQUEST['selectedSystemName'] : NULL;
$selectedSystemGuid = (isset($_REQUEST['selectedSystemGuid']) && strlen($_REQUEST['selectedSystemGuid']) > 1) ? $_REQUEST['selectedSystemGuid'] : NULL;
$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : @file_get_contents("http://ipecho.net/plain") ;

?>
<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Add Phone</li>
			<li style='display: none' id='provisionTab'>Provisioning</li>
        </ul>
        <ul id="tab">
		<form id='popup'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Add New Phone to: <?php echo $selectedSystemName ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="selectphone">Select Phone Type</label>
						<select name='selectphone' id='selectphone'>
						<option></option>
						<option value='2'>Splicecom PCS IP Phone</option>
						<option value='3'>SIP Phone</option>
						</select>
						<span class='information'>SELECT PHONE TYPE</span>
					</div>

					 <!-- pcsPhone -->
					<fieldset class='pcsPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="pcsMac">Splicecom PCS IP MAC Address</label>
						<input type='text' class='macFields' id='baseMac' name='baseMac' value='00-07-D9' readonly>
						<input type='text' class='macFields' id='pcsMac' name='pcsMac' value='' maxlength='8' >
						<span class='information'>SPLICECOM PCS IP PHONE MAC ADDRESS</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="pcsName">Splicecom PCS Phone Name</label>
						<input type='text' id='pcsName' name='pcsName' value='' >
						<span class='information'>NAME TO BE ASSIGNED TO PCS IP PHONE</span>
					</div>

					</fieldset>
					 <!-- pcsPhone -->
					
					<!-- SIPPhone -->
					<fieldset class='genericPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for='sipType'>SIP Device Model</label>
						<select name='sipType' id='sipType'>
						<option value='1'>Yealink SIP Device</value>
						<option value='2'>Generic SIP Device</value>
						</select>
						<span class='information'>SIP DEVICE MODEL</span>
					</div>
					
					<div class='field' id='yealinkMACAddress' >
						<label class='grey' for="sipMACAddress">Yealink Device MAC Address</label>
						<input type='text' id='sipMACAddress' name='sipMACAddress' value='' >
						<span class='information'>YEALINK DEVICE MAC ADDRESS</span>
					</div>
					
					<div class='field' style='display:none' id='genericIPAddress'>
						<label class='grey' for="sipIPAddress">Generic Device IP Address</label>
						<input type='text' id='sipIPAddress' name='sipIPAddress' placeholder='x.x.x.x' value='' >
						<span class='information'>GENERIC DEVICE IP ADDRESS</span>
					</div>
					
					<fieldset class='genericPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="sipName">Device Name</label>
						<input class='deviceName yealinkDevice' type='text' id='sipName' name='sipName' value='' maxlength='17' readonly>
						<span class='information'>SIP DEVICE NAME</span>
					</div>
					
					</fieldset>
					<!-- SIPPhone -->
					
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<!-- pcsPhone -->
				<fieldset class='pcsPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="pcsPlc">PCS IPPhone Partner Login Code</label>
						<input type='text' id='pcsPlc' name='pcsPlc' value='' >
						<span class='information'>PCS IP PHONES PARTNER LOGIN CODE</span>
					</div>
				</fieldset>
				<!-- pcsPhone -->
				
				<!-- commonValues -->
				<fieldset class='commonValues' style='display:none'>
				<div class='field'>
					<label class='grey' for="description">Description</label>
					<input type='text' id='description' name='description' value='' >
					<span class='information'>PHONE DESCRIPTION</span>
				</div>
				</fieldset>
				
				<fieldset class='commonValues' style='display:none'>
					<div class='field'>
						<label class='grey' for="currenthome">Registration System</label>
						<select name='currenthome' id='currenthome'>
						<option></option>
						<?php
							$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
							$info = ldap_get_entries($ds, $sr);
							for ($m=0; $m<$info['count']; $m++) {
								$homeCn = $info[$m]['cn'][0]; $homeGuid = $info[$m]['guid'][0];
								$selected = ($homeGuid == $selectedSystemGuid) ? 'selected' : '';
								echo "<option value='$homeGuid' $selected>$homeCn</option>";	
							}
						?>
						</select>
						<span class='information'>PHONE WILL BE REGISTRED TO THIS SYSTEM</span>
					</div>
					
				
					<div class='field' id='assignuserDiv'>
						<label class='grey' for="assignUserOn">Assign Phone To User</label>
						<div class='checkbox'><label for="assignUserOn"><div class="switch"><input type="checkbox" name='assignUserOn' id='assignUserOn' value="1" />
						<div class="slider"></div></div></label></div>
						<select id='assignUser' name='assignUser' value='' style='display:none' >
							<option></option>
						<?php
							$sr=ldap_list($ds,"cn=users","(objectclass=user)", array('cn','guid','agentlicense'));
							$info = ldap_get_entries($ds, $sr);
							for ($m=0; $m<$info['count']; $m++) {				
								$cn = $info[$m]['cn'][0]; 
								$guid = $info[$m]['guid'][0]; 
								$agent = $info[$m]['agentlicense'][0]; 
								
								$disabled = ($agent === '1') ? 'disabled' : '';
								echo "<option value='$guid' $disabled>$cn</option>";	
								}
						?>
						</select>
						<span class='information'>ASSIGN TO USER, CURRENT PHONE WILL BE REMOVED</span>
					</div>
					</fieldset>
					
					<div id='sipphonelicence' class='field genericPhone' style='display:none'>
						<label class='grey' for='siplicense'>SIP Phone Licence</label>
						<div class='checkbox'><label for="siplicense"><div class="switch"><input type="checkbox" name='siplicense' id='siplicense' value="1" /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE SIP PHONE LICENCE</span>
					</div>	
					<!-- commonValues -->
					
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- second tab -->
			<li>
				<h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Add New Phone to: <?php echo $selectedSystemName ?></span></h2>
				<!-- #left -->
				<div class="colLeft">
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpvendor">PnP Vendor</label>
					<input type='text' id='pnpvendor' name='pnpvendor' value='yealink' maxlength='17'>
					<span class='information'>PNP VENDOR</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpmodel">PnP Model</label>
					<input type='text' id='pnpmodel' name='pnpmodel' value='T41P' maxlength='17'>
					<span class='information'>PNP MODEL</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpversion">PnP Version</label>
					<input type='text' id='pnpversion' name='pnpversion' value='' maxlength='17'>
					<span class='information'>PNP VERSION</span>
				</div>
	
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for='stun'>Use STUN</label>
					<select name='usestun' id='usestun'>
					<option value='0'>Disable STUN</value>
					<option value='1'>Enable STUN</value>
					</select>
					<span class='information'>USE STUN SERVER</span>
				</div>
					
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="stunaddr">STUN Address</label>
					<input type='text' id='stunaddr' name='stunaddr' value='<?php echo $wanIP ?>' maxlength='64' disabled>
					<span class='information'>STUN SERVER ADDRESS</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="stunport">STUN Port</label>
					<input type='text' id='stunport' name='stunport' value='5060' maxlength='64' disabled>
					<span class='information'>STUN SERVER PORT</span>
				</div>
			
				</div> 
				<!-- #right -->
			</li>	
			<!-- second tab -->
			
			
				<input type='hidden' id='selectedSystemName' name='selectedSystemName' value='<?php echo $selectedSystemName ?>'>
				<input type='hidden' id='selectedSystemGuid' name='selectedSystemGuid' value='<?php echo $selectedSystemGuid ?>'>
				<input type='hidden' id='wanIP' name='wanIP' value='<?php echo $wanIP ?>'>
			</form>
			
			
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='save' id='addEndPoint' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/managephones/popupAdd.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 

require('../assets/inc/ldapConnect.php');
$selectedSystemName = (isset($_REQUEST['selectedSystemName']) && strlen($_REQUEST['selectedSystemName']) > 1) ? $_REQUEST['selectedSystemName'] : NULL;
$selectedSystemGuid = (isset($_REQUEST['selectedSystemGuid']) && strlen($_REQUEST['selectedSystemGuid']) > 1) ? $_REQUEST['selectedSystemGuid'] : NULL;
//$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : @file_get_contents("http://ipecho.net/plain") ;
$wanIP = (@file_get_contents("https://api.ipify.org")) ? @file_get_contents("https://api.ipify.org") : @file_get_contents("http://ipecho.net/plain");

?>
<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Add Phone</li>
			<li style='display: none' id='provisionTab'>Provisioning</li>
        </ul>
        <ul id="tab">
		<form id='popup'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Add New Phone to: <?php echo $selectedSystemName ?></span></h2>
								
				<!-- #left -->
				<div class="colLeft">

					<div class='field'>
						<label class='grey' for="selectphone">Select Phone Type</label>
						<select name='selectphone' id='selectphone'>
						<option></option>
						<option value='2'>Splicecom PCS IP Phone</option>
						<option value='3'>SIP Phone</option>
						</select>
						<span class='information'>SELECT PHONE TYPE</span>
					</div>

					 <!-- pcsPhone -->
					<fieldset class='pcsPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="pcsMac">Splicecom PCS IP MAC Address</label>
						<input type='text' class='macFields' id='baseMac' name='baseMac' value='00-07-D9' readonly>
						<input type='text' class='macFields' id='pcsMac' name='pcsMac' value='' maxlength='8' >
						<span class='information'>SPLICECOM PCS IP PHONE MAC ADDRESS</span>
					</div>
					
					<div class='field'>
						<label class='grey' for="pcsName">Splicecom PCS Phone Name</label>
						<input type='text' id='pcsName' name='pcsName' value='' >
						<span class='information'>NAME TO BE ASSIGNED TO PCS IP PHONE</span>
					</div>

					</fieldset>
					 <!-- pcsPhone -->
					
					<!-- SIPPhone -->
					<fieldset class='genericPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for='sipType'>SIP Device Model</label>
						<select name='sipType' id='sipType'>
						<option value='1'>Yealink SIP Device</value>
						<option value='2'>Generic SIP Device</value>
						</select>
						<span class='information'>SIP DEVICE MODEL</span>
					</div>
					
					<div class='field' id='yealinkMACAddress' >
						<label class='grey' for="sipMACAddress">Yealink Device MAC Address</label>
						<input type='text' id='sipMACAddress' name='sipMACAddress' value='' >
						<span class='information'>YEALINK DEVICE MAC ADDRESS</span>
					</div>
					
					<div class='field' style='display:none' id='genericIPAddress'>
						<label class='grey' for="sipIPAddress">Generic Device IP Address</label>
						<input type='text' id='sipIPAddress' name='sipIPAddress' placeholder='x.x.x.x' value='' >
						<span class='information'>GENERIC DEVICE IP ADDRESS</span>
					</div>
					
					<fieldset class='genericPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="sipName">Device Name</label>
						<input class='deviceName yealinkDevice' type='text' id='sipName' name='sipName' value='' maxlength='17' readonly>
						<span class='information'>SIP DEVICE NAME</span>
					</div>
					
					</fieldset>
					<!-- SIPPhone -->
					
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<!-- pcsPhone -->
				<fieldset class='pcsPhone' style='display:none'>
					<div class='field'>
						<label class='grey' for="pcsPlc">PCS IPPhone Partner Login Code</label>
						<input type='text' id='pcsPlc' name='pcsPlc' value='' >
						<span class='information'>PCS IP PHONES PARTNER LOGIN CODE</span>
					</div>
				</fieldset>
				<!-- pcsPhone -->
				
				<!-- commonValues -->
				<fieldset class='commonValues' style='display:none'>
				<div class='field'>
					<label class='grey' for="description">Description</label>
					<input type='text' id='description' name='description' value='' >
					<span class='information'>PHONE DESCRIPTION</span>
				</div>
				</fieldset>
				
				<fieldset class='commonValues' style='display:none'>
					<div class='field'>
						<label class='grey' for="currenthome">Registration System</label>
						<select name='currenthome' id='currenthome'>
						<option></option>
						<?php
							$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
							$info = ldap_get_entries($ds, $sr);
							for ($m=0; $m<$info['count']; $m++) {
								$homeCn = $info[$m]['cn'][0]; $homeGuid = $info[$m]['guid'][0];
								$selected = ($homeGuid == $selectedSystemGuid) ? 'selected' : '';
								echo "<option value='$homeGuid' $selected>$homeCn</option>";	
							}
						?>
						</select>
						<span class='information'>PHONE WILL BE REGISTRED TO THIS SYSTEM</span>
					</div>
					
				
					<div class='field' id='assignuserDiv'>
						<label class='grey' for="assignUserOn">Assign Phone To User</label>
						<div class='checkbox'><label for="assignUserOn"><div class="switch"><input type="checkbox" name='assignUserOn' id='assignUserOn' value="1" />
						<div class="slider"></div></div></label></div>
						<select id='assignUser' name='assignUser' value='' style='display:none' >
							<option></option>
						<?php
							$sr=ldap_list($ds,"cn=users","(objectclass=user)", array('cn','guid','agentlicense'));
							$info = ldap_get_entries($ds, $sr);
							for ($m=0; $m<$info['count']; $m++) {				
								$cn = $info[$m]['cn'][0]; 
								$guid = $info[$m]['guid'][0]; 
								$agent = $info[$m]['agentlicense'][0]; 
								
								$disabled = ($agent === '1') ? 'disabled' : '';
								echo "<option value='$guid' $disabled>$cn</option>";	
								}
						?>
						</select>
						<span class='information'>ASSIGN TO USER, CURRENT PHONE WILL BE REMOVED</span>
					</div>
					</fieldset>
					
					<div id='sipphonelicence' class='field genericPhone' style='display:none'>
						<label class='grey' for='siplicense'>SIP Phone Licence</label>
						<div class='checkbox'><label for="siplicense"><div class="switch"><input type="checkbox" name='siplicense' id='siplicense' value="1" /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE SIP PHONE LICENCE</span>
					</div>	
					<!-- commonValues -->
					
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			<!-- second tab -->
			<li>
				<h2><span id='FormIcon' class='icon-phone'></span> <span id='FormText'>Add New Phone to: <?php echo $selectedSystemName ?></span></h2>
				<!-- #left -->
				<div class="colLeft">
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpvendor">PnP Vendor</label>
					<input type='text' id='pnpvendor' name='pnpvendor' value='yealink' maxlength='17'>
					<span class='information'>PNP VENDOR</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpmodel">PnP Model</label>
					<input type='text' id='pnpmodel' name='pnpmodel' value='T41P' maxlength='17'>
					<span class='information'>PNP MODEL</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="pnpversion">PnP Version</label>
					<input type='text' id='pnpversion' name='pnpversion' value='' maxlength='17'>
					<span class='information'>PNP VERSION</span>
				</div>
	
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for='stun'>Use STUN</label>
					<select name='usestun' id='usestun'>
					<option value='0'>Disable STUN</value>
					<option value='1'>Enable STUN</value>
					</select>
					<span class='information'>USE STUN SERVER</span>
				</div>
					
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="stunaddr">STUN Address</label>
					<input type='text' id='stunaddr' name='stunaddr' value='<?php echo $wanIP ?>' maxlength='64' disabled>
					<span class='information'>STUN SERVER ADDRESS</span>
				</div>
				
				<fieldset class='genericPhone' style='display:none'>
				<div class='field'>
					<label class='grey' for="stunport">STUN Port</label>
					<input type='text' id='stunport' name='stunport' value='5060' maxlength='64' disabled>
					<span class='information'>STUN SERVER PORT</span>
				</div>
			
				</div> 
				<!-- #right -->
			</li>	
			<!-- second tab -->
			
			
				<input type='hidden' id='selectedSystemName' name='selectedSystemName' value='<?php echo $selectedSystemName ?>'>
				<input type='hidden' id='selectedSystemGuid' name='selectedSystemGuid' value='<?php echo $selectedSystemGuid ?>'>
				<input type='hidden' id='wanIP' name='wanIP' value='<?php echo $wanIP ?>'>
			</form>
			
			
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='save' id='addEndPoint' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>
